@@ -1,13 +1,15 @@
 import json
-
 import pandas as pd
-
+from numpy import nan
 from powerbot_backtesting.utils.constants import NORDPOOL_EIC_CODES, SYSTEMS
 
 
 def _historic_contract_transformation(path_to_file: str, exchange: str) -> pd.DataFrame:
     if exchange in SYSTEMS["M7"]:
-        index = pd.json_normalize(json.load(open(path_to_file)))[
+        index = pd.json_normalize(json.load(open(path_to_file)))
+        if "details.undrlngContracts.contractId" not in index.columns:
+            index["details.undrlngContracts.contractId"] = nan
+        index = index[
             ["deliveryAreas", "deliveryEnd", "deliveryStart", "details.contractId", "details.prod", "details.actPoint",
              "details.expPoint", "details.undrlngContracts.contractId"]]
     else:
@@ -38,8 +40,11 @@ def _historic_data_transformation(files: list, exchange: str, filetype: str) ->
     # Append contracts that are in the same timeframe to one DataFrame
     lst = []
     for file in files:
-        lst.append(pd.read_json(file))
-        df = pd.concat(lst, ignore_index=True)
+        try:
+            lst.append(pd.read_json(file))
+            df = pd.concat(lst, ignore_index=True)
+        except ValueError:
+            continue
 
     if exchange in SYSTEMS["M7"]:
         if filetype == "trades":
