@@ -6,8 +6,7 @@ import pandas as pd
 import pytest
 from dateutil.tz import tzutc
 from powerbot_client import ApiClient
-
-from tests.helpers import random_params_api  # noqa
+from helpers import random_params_api  # noqa
 
 
 @pytest.mark.parametrize("rndm_params",
