@@ -1,15 +1,14 @@
 import gzip
-from datetime import datetime, timezone, timedelta
-from pathlib import Path
-
 import numpy as np
 import pandas as pd
 import pytest
 
+from datetime import datetime, timezone, timedelta
+from pathlib import Path
 from powerbot_backtesting import HistoryExporter, ApiExporter
 from powerbot_backtesting.models import HistoryApiClient
-from tests.helpers import random_params_history_cleanup, random_params_history_no_cleanup  # noqa
-from tests.config import config
+from helpers import random_params_history_cleanup, random_params_history_no_cleanup  # noqa
+from config import config
 
 
 @pytest.mark.parametrize("rndm_params",
